==> zio-aws-backupgateway_3-5.17.271.1-sources.jar: zio/aws/backupgateway/model/package.scala <==
package zio.aws.backupgateway
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.backupgateway.model.primitives.TagKey
import zio.aws.backupgateway.model.primitives.Path.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object ActivationKey extends Subtype[String]
    type ActivationKey =
      zio.aws.backupgateway.model.primitives.ActivationKey.Type
    object DayOfMonth extends Subtype[Int]
    type DayOfMonth = zio.aws.backupgateway.model.primitives.DayOfMonth.Type
    object DayOfWeek extends Subtype[Int]
    type DayOfWeek = zio.aws.backupgateway.model.primitives.DayOfWeek.Type
    object GatewayArn extends Subtype[String]
    type GatewayArn = zio.aws.backupgateway.model.primitives.GatewayArn.Type
    object Host extends Subtype[String]
    type Host = zio.aws.backupgateway.model.primitives.Host.Type
    object HourOfDay extends Subtype[Int]
    type HourOfDay = zio.aws.backupgateway.model.primitives.HourOfDay.Type
    object HypervisorId extends Subtype[String]
    type HypervisorId = zio.aws.backupgateway.model.primitives.HypervisorId.Type
    object KmsKeyArn extends Subtype[String]
    type KmsKeyArn = zio.aws.backupgateway.model.primitives.KmsKeyArn.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.backupgateway.model.primitives.MaxResults.Type
    object MinuteOfHour extends Subtype[Int]
    type MinuteOfHour = zio.aws.backupgateway.model.primitives.MinuteOfHour.Type
    object Name extends Subtype[String]
    type Name = zio.aws.backupgateway.model.primitives.Name.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.backupgateway.model.primitives.NextToken.Type
    object Password extends Subtype[String]
    type Password = zio.aws.backupgateway.model.primitives.Password.Type
    object Path extends Subtype[String]
    type Path = zio.aws.backupgateway.model.primitives.Path.Type
    object ResourceArn extends Subtype[String]
    type ResourceArn = zio.aws.backupgateway.model.primitives.ResourceArn.Type
    object ServerArn extends Subtype[String]
    type ServerArn = zio.aws.backupgateway.model.primitives.ServerArn.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.backupgateway.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.backupgateway.model.primitives.TagValue.Type
    object Time extends Subtype[Instant]
    type Time = zio.aws.backupgateway.model.primitives.Time.Type
    object Username extends Subtype[String]
    type Username = zio.aws.backupgateway.model.primitives.Username.Type
    object VpcEndpoint extends Subtype[String]
    type VpcEndpoint = zio.aws.backupgateway.model.primitives.VpcEndpoint.Type
  }
  type Gateways = List[zio.aws.backupgateway.model.Gateway]
  type Hypervisors = List[zio.aws.backupgateway.model.Hypervisor]
  type TagKeys = List[TagKey]
  type Tags = List[zio.aws.backupgateway.model.Tag]
  type VirtualMachines = List[zio.aws.backupgateway.model.VirtualMachine]
}

==> zio-aws-backupgateway_3-5.19.7.3-sources.jar: zio/aws/backupgateway/model/package.scala <==
package zio.aws.backupgateway
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.backupgateway.model.primitives.{TagKey, DayOfWeek}
import zio.aws.backupgateway.model.primitives.LogGroupArn.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object ActivationKey extends Subtype[String]
    type ActivationKey =
      zio.aws.backupgateway.model.primitives.ActivationKey.Type
    object AverageUploadRateLimit extends Subtype[Long]
    type AverageUploadRateLimit =
      zio.aws.backupgateway.model.primitives.AverageUploadRateLimit.Type
    object DayOfMonth extends Subtype[Int]
    type DayOfMonth = zio.aws.backupgateway.model.primitives.DayOfMonth.Type
    object DayOfWeek extends Subtype[Int]
    type DayOfWeek = zio.aws.backupgateway.model.primitives.DayOfWeek.Type
    object GatewayArn extends Subtype[String]
    type GatewayArn = zio.aws.backupgateway.model.primitives.GatewayArn.Type
    object Host extends Subtype[String]
    type Host = zio.aws.backupgateway.model.primitives.Host.Type
    object HourOfDay extends Subtype[Int]
    type HourOfDay = zio.aws.backupgateway.model.primitives.HourOfDay.Type
    object HypervisorId extends Subtype[String]
    type HypervisorId = zio.aws.backupgateway.model.primitives.HypervisorId.Type
    object IamRoleArn extends Subtype[String]
    type IamRoleArn = zio.aws.backupgateway.model.primitives.IamRoleArn.Type
    object KmsKeyArn extends Subtype[String]
    type KmsKeyArn = zio.aws.backupgateway.model.primitives.KmsKeyArn.Type
    object LogGroupArn extends Subtype[String]
    type LogGroupArn = zio.aws.backupgateway.model.primitives.LogGroupArn.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.backupgateway.model.primitives.MaxResults.Type
    object MinuteOfHour extends Subtype[Int]
    type MinuteOfHour = zio.aws.backupgateway.model.primitives.MinuteOfHour.Type
    object Name extends Subtype[String]
    type Name = zio.aws.backupgateway.model.primitives.Name.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.backupgateway.model.primitives.NextToken.Type
    object Password extends Subtype[String]
    type Password = zio.aws.backupgateway.model.primitives.Password.Type
    object Path extends Subtype[String]
    type Path = zio.aws.backupgateway.model.primitives.Path.Type
    object ResourceArn extends Subtype[String]
    type ResourceArn = zio.aws.backupgateway.model.primitives.ResourceArn.Type
    object ServerArn extends Subtype[String]
    type ServerArn = zio.aws.backupgateway.model.primitives.ServerArn.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.backupgateway.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.backupgateway.model.primitives.TagValue.Type
    object Time extends Subtype[Instant]
    type Time = zio.aws.backupgateway.model.primitives.Time.Type
    object Username extends Subtype[String]
    type Username = zio.aws.backupgateway.model.primitives.Username.Type
    object VmwareCategory extends Subtype[String]
    type VmwareCategory =
      zio.aws.backupgateway.model.primitives.VmwareCategory.Type
    object VmwareTagName extends Subtype[String]
    type VmwareTagName =
      zio.aws.backupgateway.model.primitives.VmwareTagName.Type
    object VpcEndpoint extends Subtype[String]
    type VpcEndpoint = zio.aws.backupgateway.model.primitives.VpcEndpoint.Type
  }
  type BandwidthRateLimitIntervals =
    List[zio.aws.backupgateway.model.BandwidthRateLimitInterval]
  type DaysOfWeek = List[DayOfWeek]
  type Gateways = List[zio.aws.backupgateway.model.Gateway]
  type Hypervisors = List[zio.aws.backupgateway.model.Hypervisor]
  type TagKeys = List[TagKey]
  type Tags = List[zio.aws.backupgateway.model.Tag]
  type VirtualMachines = List[zio.aws.backupgateway.model.VirtualMachine]
  type VmwareTags = List[zio.aws.backupgateway.model.VmwareTag]
  type VmwareToAwsTagMappings =
    List[zio.aws.backupgateway.model.VmwareToAwsTagMapping]
}
